==> haskell-git-lfs-1.2.3-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-git-lfs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 git-lfs
version:              1.2.3
visibility:           public
id:                   git-lfs-1.2.3-FbneVdf6YWynDMfPOxrcv
key:                  git-lfs-1.2.3-FbneVdf6YWynDMfPOxrcv
license:              AGPL-3.0-only
copyright:            2019 Joey Hess
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
stability:            Stable
synopsis:             git-lfs protocol
description:          An implementation of the git-lfs protocol.
category:             Network
abi:                  7cbd402896230dbf9f2fb73bdbea9b28
exposed:              True
exposed-modules:      Network.GitLFS
import-dirs:          /usr/lib/ghc-9.4.8/site-local/git-lfs-1.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/git-lfs-1.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/git-lfs-1.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-git-lfs
hs-libraries:         HSgit-lfs-1.2.3-FbneVdf6YWynDMfPOxrcv
depends:
    aeson-2.1.2.1-JiLBJfeE1bfHXFEKMVOO2u base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-FZkso54i68UDZy9QWLkbnV
    containers-0.6.7 http-client-0.7.18-9AKDNI7KeMdGO3pPIP3UL1
    http-types-0.12.4-A1oxPTNXSXlBA9G2ubwbl6
    network-uri-2.6.4.2-APaQU0Ye6OaKm6pWDY2rCG text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-git-lfs/html/git-lfs.haddock
haddock-html:         /usr/share/doc/haskell-git-lfs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-git-lfs-1.2.3-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-git-lfs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 git-lfs
version:              1.2.3
visibility:           public
id:                   git-lfs-1.2.3-9nuwYbgogBAG3zHMKRh5ZO
key:                  git-lfs-1.2.3-9nuwYbgogBAG3zHMKRh5ZO
license:              AGPL-3.0-only
copyright:            2019 Joey Hess
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
stability:            Stable
synopsis:             git-lfs protocol
description:          An implementation of the git-lfs protocol.
category:             Network
abi:                  1b8e9ddb6200aa8d6afd80f9d3380cfe
exposed:              True
exposed-modules:      Network.GitLFS
import-dirs:          /usr/lib/ghc-9.4.8/site-local/git-lfs-1.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/git-lfs-1.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/git-lfs-1.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-git-lfs
hs-libraries:         HSgit-lfs-1.2.3-9nuwYbgogBAG3zHMKRh5ZO
depends:
    aeson-2.1.2.1-DzmMfEZgdOFRIaYChwLwW base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-FZkso54i68UDZy9QWLkbnV
    containers-0.6.7 http-client-0.7.18-42krpIx96u9GMwVLyBpcGw
    http-types-0.12.4-679DcLxXQEvalr11Ew75E
    network-uri-2.6.4.2-APaQU0Ye6OaKm6pWDY2rCG text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-git-lfs/html/git-lfs.haddock
haddock-html:         /usr/share/doc/haskell-git-lfs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
